==> nh2k-a_2_0_0-src.zip: win/win32/res/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by NetHack.rc
//
#define BUTTON_RESET                    3
#define IDD_ABOUT1                      616
#define IDD_ABOUT2                      617
#define IDD_ABOUT3                      618
#define IDD_ABOUT4                      619
#define IDD_ABOUT5                      620
#define IDD_ABOUT6                      621
#define IDD_ABOUT7                      622
#define IDD_ABOUT8                      623
#define IDD_ABOUT9                      624
#define IDD_ABOUT10                     625
#define IDD_ABOUT11                     626
#define IDD_ABOUT12                     627
#define EDIT_DELAY                      1003
#define EDIT_HEIGHT                     1004
#define CHECK_SHOWMORE                  1004
#define CHECK_BAR                       1004
#define CHECK_CURSORKEY                 1004
#define CHECK_MICRO                     1005
#define CHECK_DETAIL                    1005
#define RADIO_TILE                      1008
#define RADIO_CHAR                      1009
#define SPIN_WIDTH                      1012
#define SPIN_HEIGHT                     1013
#define EDIT_WIDTH                      1014
#define RADIO_DEFAULT                   1015
#define RADIO_ENTIRE                    1016
#define STATIC_ESW1                     1028
#define STATIC_ESH1                     1030
#define RADIO_TOP                       1032
#define RADIO_BOTTOM                    1033
#define RADIO_SOUNDON                   1034
#define IDC_LIST1                       1035
#define RADIO_SOUNDOFF                  1035
#define LIST_CONTROL                    1035
#define EDIT_LINES                      1037
#define IDC_PROGRESS1                   1041
#define PROGRESS_LOAD                   1041
#define STATIC_FONT                     1068
#define BUTTON_FONT                     1069
#define SPIN_LINES                      1073
#define STATIC_TITLE                    1078
#define RADIO_ORIGINAL                  1079
#define RADIO_ADVANCED                  1080
#define CHECK_EFFECT                    1082
#define STATIC_QUERY                    1090
#define IDC_RADIO1                      1092
#define IDC_RADIO2                      1093
#define EDIT_ANSWER                     10080
#define IDM_CONFIGMAP                   40006
#define IDM_CONFIGMESSAGE               40008
#define IDM_CONFIGSTATUS                40009
#define IDM_CONFIGMENU                  40010
#define IDM_CONFIGSYS                   40011
#define IDM_INV_ALL                     40017
#define IDM_VERSION                     40019
#define IDM_SYMBOL                      40021
#define IDM_UP                          40022
#define IDM_DOWN                        40023
#define IDM_REST                        40024
#define IDM_APPLY                       40025
#define IDM_TAKEOFF_SELECT              40026
#define IDM_TAKEOFF_ARMOR               40027
#define IDM_TAKEOFF_ACC                 40028
#define IDM_REDO                        40029
#define IDM_CLOSE                       40030
#define IDM_MONNAME                     40032
#define IDM_DROP                        40034
#define IDM_DROP_SELECT                 40035
#define IDM_KICK                        40036
#define IDM_EAT                         40037
#define IDM_ENGRAVE                     40038
#define IDM_INV_GOLD                    40039
#define IDM_INV_UNPAID                  40040
#define IDM_INV_USED                    40041
#define IDM_OPEN                        40043
#define IDM_OPTION                      40044
#define IDM_PAY                         40045
#define IDM_WEAR_RING                   40046
#define IDM_PREV                        40047
#define IDM_QUAFF                       40048
#define IDM_READ                        40049
#define IDM_REDRAW                      40050
#define IDM_SEARCH                      40051
#define IDM_THROW                       40052
#define IDM_TELEPORT                    40054
#define IDM_HISTORY                     40055
#define IDM_WEAR_WEAPON                 40056
#define IDM_TAKEOFF_WEAPON              40057
#define IDM_WEAR_ARMOR                  40058
#define IDM_SPELLLIST                   40059
#define IDM_DISCOVER                    40060
#define IDM_ZAP                         40061
#define IDM_CASTSPELL                   40062
#define IDM_FLOOR                       40064
#define IDM_PICKUP                      40065
#define IDM_AUTOPICKUP                  40066
#define IDM_CHECKTRAP                   40067
#define IDM_INV_WEAPON                  40068
#define IDM_INV_ARMOR                   40069
#define IDM_INV_RING                    40070
#define IDM_INV_AMULET                  40071
#define IDM_INV_TOOL                    40072
#define IDM_DISCOVERITEM                40074
#define IDM_ADJUST                      40076
#define IDM_CHAT                        40077
#define IDM_DIP                         40078
#define IDM_ENHANCE                     40079
#define IDM_FORCE                       40080
#define IDM_INVOKE                      40081
#define IDM_JUMP                        40082
#define IDM_LOOT                        40083
#define IDM_MONSTER                     40084
#define IDM_NAME                        40085
#define IDM_OFFER                       40086
#define IDM_PRAY                        40087
#define IDM_RUB                         40088
#define IDM_SIT                         40089
#define IDM_TURNUNDEAD                  40090
#define IDM_UNTRAP                      40091
#define IDM_COMPILEOPTION               40092
#define IDM_WIPE                        40093
#define IDM_NUMBER                      40094
#define IDM_ORIGINAL                    40095
#define IDM_COPYMAPTEXT                 40096
#define IDM_COPYMAPDIB                  40097
#define IDM_COPYMESSAGE                 40098
#define IDM_COPYMENU                    40099
#define IDM_HELP                        40100
#define IDM_QUITGAME                    40101
#define IDM_SAVEGAME                    40102
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        163
#define _APS_NEXT_COMMAND_VALUE         40103
#define _APS_NEXT_CONTROL_VALUE         1093
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> nh2k-a_3_1_0-src.zip: win/win32/res/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by NetHack.rc
//
#define BUTTON_RESET                    3
#define IDD_ABOUT1                      616
#define IDD_ABOUT2                      617
#define IDD_ABOUT3                      618
#define IDD_ABOUT4                      619
#define IDD_ABOUT5                      620
#define IDD_ABOUT6                      621
#define IDD_ABOUT7                      622
#define IDD_ABOUT8                      623
#define IDD_ABOUT9                      624
#define IDD_ABOUT10                     625
#define IDD_ABOUT11                     626
#define IDD_ABOUT12                     627
#define EDIT_DELAY                      1003
#define EDIT_HEIGHT                     1004
#define CHECK_SHOWMORE                  1004
#define CHECK_BAR                       1004
#define CHECK_CURSORKEY                 1004
#define CHECK_MICRO                     1005
#define CHECK_DETAIL                    1005
#define RADIO_TILE                      1008
#define RADIO_CHAR                      1009
#define SPIN_WIDTH                      1012
#define SPIN_HEIGHT                     1013
#define EDIT_WIDTH                      1014
#define RADIO_DEFAULT                   1015
#define RADIO_ENTIRE                    1016
#define STATIC_ESW1                     1028
#define STATIC_ESH1                     1030
#define RADIO_TOP                       1032
#define RADIO_BOTTOM                    1033
#define RADIO_SOUNDON                   1034
#define IDC_LIST1                       1035
#define RADIO_SOUNDOFF                  1035
#define LIST_CONTROL                    1035
#define EDIT_LINES                      1037
#define IDC_PROGRESS1                   1041
#define PROGRESS_LOAD                   1041
#define STATIC_FONT                     1068
#define BUTTON_FONT                     1069
#define SPIN_LINES                      1073
#define STATIC_TITLE                    1078
#define RADIO_ORIGINAL                  1079
#define RADIO_ADVANCED                  1080
#define CHECK_EFFECT                    1082
#define STATIC_QUERY                    1090
#define IDC_RADIO1                      1092
#define IDC_RADIO2                      1093
#define EDIT_ANSWER                     10080
#define IDM_CONFIGMAP                   40006
#define IDM_CONFIGMESSAGE               40008
#define IDM_CONFIGSTATUS                40009
#define IDM_CONFIGMENU                  40010
#define IDM_CONFIGSYS                   40011
#define IDM_INV_ALL                     40017
#define IDM_VERSION                     40019
#define IDM_SYMBOL                      40021
#define IDM_UP                          40022
#define IDM_DOWN                        40023
#define IDM_REST                        40024
#define IDM_APPLY                       40025
#define IDM_TAKEOFF_SELECT              40026
#define IDM_TAKEOFF_ARMOR               40027
#define IDM_TAKEOFF_ACC                 40028
#define IDM_REDO                        40029
#define IDM_CLOSE                       40030
#define IDM_MONNAME                     40032
#define IDM_DROP                        40034
#define IDM_DROP_SELECT                 40035
#define IDM_KICK                        40036
#define IDM_EAT                         40037
#define IDM_ENGRAVE                     40038
#define IDM_INV_GOLD                    40039
#define IDM_INV_UNPAID                  40040
#define IDM_INV_USED                    40041
#define IDM_OPEN                        40043
#define IDM_OPTION                      40044
#define IDM_PAY                         40045
#define IDM_WEAR_RING                   40046
#define IDM_PREV                        40047
#define IDM_QUAFF                       40048
#define IDM_READ                        40049
#define IDM_REDRAW                      40050
#define IDM_SEARCH                      40051
#define IDM_THROW                       40052
#define IDM_TELEPORT                    40054
#define IDM_HISTORY                     40055
#define IDM_WEAR_WEAPON                 40056
#define IDM_TAKEOFF_WEAPON              40057
#define IDM_WEAR_ARMOR                  40058
#define IDM_SPELLLIST                   40059
#define IDM_DISCOVER                    40060
#define IDM_ZAP                         40061
#define IDM_CASTSPELL                   40062
#define IDM_FLOOR                       40064
#define IDM_PICKUP                      40065
#define IDM_AUTOPICKUP                  40066
#define IDM_CHECKTRAP                   40067
#define IDM_INV_WEAPON                  40068
#define IDM_INV_ARMOR                   40069
#define IDM_INV_RING                    40070
#define IDM_INV_AMULET                  40071
#define IDM_INV_TOOL                    40072
#define IDM_DISCOVERITEM                40074
#define IDM_ADJUST                      40076
#define IDM_CHAT                        40077
#define IDM_DIP                         40078
#define IDM_ENHANCE                     40079
#define IDM_FORCE                       40080
#define IDM_INVOKE                      40081
#define IDM_JUMP                        40082
#define IDM_LOOT                        40083
#define IDM_MONSTER                     40084
#define IDM_NAME                        40085
#define IDM_OFFER                       40086
#define IDM_PRAY                        40087
#define IDM_RUB                         40088
#define IDM_SIT                         40089
#define IDM_TURNUNDEAD                  40090
#define IDM_UNTRAP                      40091
#define IDM_COMPILEOPTION               40092
#define IDM_WIPE                        40093
#define IDM_NUMBER                      40094
#define IDM_ORIGINAL                    40095
#define IDM_COPYMAPTEXT                 40096
#define IDM_COPYMAPDIB                  40097
#define IDM_COPYMESSAGE                 40098
#define IDM_COPYMENU                    40099
#define IDM_HELP                        40100
#define IDM_QUITGAME                    40101
#define IDM_SAVEGAME                    40102
#define IDM_QUIVER                      40103
#define IDM_XCHANGE                     40104
#define IDM_CMD_CANCEL                  40105
#define IDM_FIRE                        40106
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        164
#define _APS_NEXT_COMMAND_VALUE         40107
#define _APS_NEXT_CONTROL_VALUE         1093
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
